@import url("https://fonts.googleapis.com/css2?family=Arvo&display=swap");

/* Setting Font Arvo Serif */
div.inner_cell, div.jp-MarkdownOutput {
    font-family: 'Arvo', serif !important;
}

/* Setting Font for elements which may get Overridden */
.content-header, ul.table-of-content-list li, div.markdown-container {
    font-family: 'Arvo', serif !important;
}

h1.content-header, h2.content-header, h3.content-header, h4.content-header {
    border-bottom-left-radius: 50px;
    border-top-right-radius: 50px;
    border-right: 4px solid;
    border-left: 4px solid;
    text-align: center;
    padding: 4px;
}

ul.table-of-content-list {
    border-top-right-radius: 30px;
    border-bottom-left-radius: 30px;
    border-right: 4px solid;
    border-left: 4px solid;
    padding: 10px;
}

ul.table-of-content-list li {
    margin-top: 10px;
}

ul.table-of-content-list.large a {
    font-size: 18px;
}

ul.table-of-content-list a {
    text-decoration: none !important;
    font-size: 15px;
}

ul.table-of-content-list.small a {
    font-size: 12px;
}

ul.table-of-content-list a:hover {
    text-decoration: underline !important;
}

div.markdown-container {
    border-right: 4px solid;
    border-left: 4px solid;
    padding: 5px 10px;
    border-radius: 8px;
    margin: 8px 0px;
}
